# Authors

## Main developer

Matteo Bunino \<[matteo.bunino@cern.ch](mailto:matteo.bunino@cern.ch)\>  

## Contributors

[All contributors](https://github.com/interTwin-eu/T6.5-AI-and-ML/graphs/contributors)
